## $Id: fileviewlets.py 12240 2014-12-15 07:44:01Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import grok
from waeup.ikoba.interfaces import MessageFactory as _
from waeup.ikoba.interfaces import PUBLISHED
from waeup.ikoba.browser.layout import UtilityView
from waeup.ikoba.browser.fileviewlets import (
    FileDisplay, FileUpload, Image)

from waeup.ikoba.documents.document import PDFDocument
from waeup.ikoba.documents.browser import (
    DocumentManageFormPage, DocumentDisplayFormPage)


# File viewlets for documents

class PDFScanManageUpload(FileUpload):
    """Scan upload viewlet for officers.
    """
    grok.view(DocumentManageFormPage)
    grok.context(PDFDocument)
    grok.require('waeup.manageDocuments')
    label = _(u'PDF File')
    title = _(u'PDF File')
    mus = 1024 * 200
    download_name = u'sample.pdf'
    tab_redirect = '#tab2'


class PDFScanDisplay(FileDisplay):
    """Scan display viewlet.
    """
    grok.order(1)
    grok.context(PDFDocument)
    grok.require('waeup.viewDocuments')
    grok.view(DocumentDisplayFormPage)
    label = _(u'PDF Scan')
    title = _(u'PDF Scan')
    download_name = u'sample.pdf'


class PDFScanImage(Image, UtilityView):
    """Scan document.
    """
    ##: Needs to be protected if not published
    grok.name('sample.pdf')
    grok.context(PDFDocument)
    grok.require('waeup.Public')
    download_name = u'sample.pdf'

    def render(self):
        if self.context.state != PUBLISHED:
            self.flash(_('The document requested has not yet been published.'),
                type="warning")
            self.redirect(self.url(self.context))
            return
        return super(PDFScanImage, self).render()

